<html><head>
<script src="https://cdnjs.cloudflare.com/ajax/libs/jquery/3.2.1/jquery.min.js"></script>
    <script>
//setInterval(function(){ $.get("/dll/refresh/", function(){}); }, 5000);
</script>
<style>

.footer {
  position: fixed;
  right: 0;
  bottom: 0;
  left: 0;
  padding: 1rem;
  background-color: #333;
  color: white;
  text-align: center;
}
.header {
  position: fixed;
  right: 0;
  top: 0;
  left: 0;
  padding: 1rem;
  background-color: #333;
  color: white;
  text-align: center;
}
.content {
  margin-top:50px;
  margin-bottom:80px;
}
body {
    display: block;
    font-family: monospace;
    white-space: pre;
    margin: 1em 0px 1em;
    padding-bottom: 100px;
    padding-left: 10px;
}
</style></head>


<body>
<div class="header"><strong>Django Live Log</strong></div>
<div class="footer"><strong>dll © registered.</strong></div>
{{result}}
</body></html>